==> ministra-5.6.8.zip: stalker_portal/admin/functions.php <==
<?php

use Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\b009b335728cd8e4f099e9618546ca1d9\w845d00e5e868e310b57a6544b77e6aae;
use Silex\Application;
use Symfony\Component\HttpFoundation\Request;
if (!\function_exists('admin_controller_resolver')) {
    function admin_controller_resolver()
    {
        $app = $namespace = $controller = $action = \null;
        $variables = ['app', 'namespace', 'controller', 'action'];
        $func_args = \func_get_args();
        foreach ($func_args as $key => $val) {
            ${$variables[$key]} = $val;
        }
        $action = !empty($action) ? \str_replace('-', '_', $action) : 'index';
        $controllerName = "\\{$namespace}\\" . \implode('', \array_map('ucfirst', \explode('-', \strtolower($controller)))) . 'Controller';
        if (\class_exists($controllerName) && \method_exists($controllerName, $action)) {
            $controller = new $controllerName($app);
            if ($controller instanceof $controllerName) {
                if (\is_callable([$controller, $action])) {
                    $reflection = new \ReflectionClass(\get_class($controller));
                    $method = $reflection->getMethod($action);
                    $parameters = $method->getParameters();
                    $request = $app['request_stack']->getCurrentRequest();
                    $resolved = [];
                    foreach ($parameters as $parameter) {
                        $class = $parameter->getClass();
                        if ($class) {
                            if ($class->getName() === \Silex\Application::class) {
                                $resolved[] = $app;
                            } else {
                                if ($class->getName() === \Symfony\Component\HttpFoundation\Request::class || \class_implements(\Symfony\Component\HttpFoundation\Request::class, $class->getName())) {
                                    $resolved[] = $request;
                                } else {
                                    $resolved[] = $app[$class->getName()];
                                }
                            }
                            continue;
                        }
                        $value = $request->get($parameter->getName(), \null);
                        if (\null === $value) {
                            if (!$parameter->isDefaultValueAvailable()) {
                                throw new \InvalidArgumentException("Argument `{$parameter->getName()}` for {$controllerName}::{$action} does not defined");
                            }
                            $value = $parameter->getDefaultValue();
                        }
                        $resolved[] = $value;
                    }
                    return \call_user_func_array([$controller, $action], $resolved);
                }
            }
        }
        return $app->abort(404, \sprintf('No route found for: %s:%s', $controllerName, $action));
    }
}
if (!\function_exists('optionsConcat')) {
    function optionsConcat(&$var, $fields = [], $options = [])
    {
        foreach ($fields as $field) {
            if (!empty($options[$field])) {
                $var .= $options[$field];
            }
        }
    }
}
if (!\function_exists('adminLogError')) {
    function adminLogError(\Silex\Application $app, $e)
    {
        $message = $e->getMessage() . \PHP_EOL . $e->getTraceAsString();
        if ($app->offsetExists('monolog')) {
            $app->offsetGet('monolog')->error($message);
        } else {
            \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\b009b335728cd8e4f099e9618546ca1d9\w845d00e5e868e310b57a6544b77e6aae::z3182eef79ddc9f24d927475892878e57($message);
        }
    }
}

==> ministra-5.6.10.zip: stalker_portal/admin/functions.php <==
<?php

use Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\e19b518dccc8206e14e113c869a7ec85\f1f42f11d53cbf1a52b00c3e1008054b3;
use Silex\Application;
use Symfony\Component\HttpFoundation\Request;
if (!\function_exists('admin_controller_resolver')) {
    function admin_controller_resolver()
    {
        $app = $namespace = $controller = $action = \null;
        $variables = ['app', 'namespace', 'controller', 'action'];
        $func_args = \func_get_args();
        foreach ($func_args as $key => $val) {
            ${$variables[$key]} = $val;
        }
        $action = !empty($action) ? \str_replace('-', '_', $action) : 'index';
        $controllerName = "\\{$namespace}\\" . \implode('', \array_map('ucfirst', \explode('-', \strtolower($controller)))) . 'Controller';
        if (\class_exists($controllerName) && \method_exists($controllerName, $action)) {
            $controller = new $controllerName($app);
            if ($controller instanceof $controllerName) {
                if (\is_callable([$controller, $action])) {
                    $reflection = new \ReflectionClass(\get_class($controller));
                    $method = $reflection->getMethod($action);
                    $parameters = $method->getParameters();
                    $request = $app['request_stack']->getCurrentRequest();
                    $resolved = [];
                    foreach ($parameters as $parameter) {
                        $class = $parameter->getClass();
                        if ($class) {
                            if ($class->getName() === \Silex\Application::class) {
                                $resolved[] = $app;
                            } else {
                                if ($class->getName() === \Symfony\Component\HttpFoundation\Request::class || \class_implements(\Symfony\Component\HttpFoundation\Request::class, $class->getName())) {
                                    $resolved[] = $request;
                                } else {
                                    $resolved[] = $app[$class->getName()];
                                }
                            }
                            continue;
                        }
                        $value = $request->get($parameter->getName(), \null);
                        if (\null === $value) {
                            if (!$parameter->isDefaultValueAvailable()) {
                                throw new \InvalidArgumentException("Argument `{$parameter->getName()}` for {$controllerName}::{$action} does not defined");
                            }
                            $value = $parameter->getDefaultValue();
                        }
                        $resolved[] = $value;
                    }
                    return \call_user_func_array([$controller, $action], $resolved);
                }
            }
        }
        return $app->abort(404, \sprintf('No route found for: %s:%s', $controllerName, $action));
    }
}
if (!\function_exists('optionsConcat')) {
    function optionsConcat(&$var, $fields = [], $options = [])
    {
        foreach ($fields as $field) {
            if (!empty($options[$field])) {
                $var .= $options[$field];
            }
        }
    }
}
if (!\function_exists('adminLogError')) {
    function adminLogError(\Silex\Application $app, $e)
    {
        $message = $e->getMessage() . \PHP_EOL . $e->getTraceAsString();
        if ($app->offsetExists('monolog')) {
            $app->offsetGet('monolog')->error($message);
        } else {
            \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\e19b518dccc8206e14e113c869a7ec85\f1f42f11d53cbf1a52b00c3e1008054b3::E4651a75e1d26d4497bcc14b5ba73cb1f($message);
        }
    }
}
